# mypy-boto3-apigatewayv2<a id="mypy-boto3-apigatewayv2"></a>

[![PyPI - mypy-boto3-apigatewayv2](https://img.shields.io/pypi/v/mypy-boto3-apigatewayv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-apigatewayv2)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-apigatewayv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-apigatewayv2)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-apigatewayv2?color=blue)](https://pypistats.org/packages/mypy-boto3-apigatewayv2)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.ApiGatewayV2 1.17.84](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/apigatewayv2.html#ApiGatewayV2)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.14.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-apigatewayv2 docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_apigatewayv2/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-apigatewayv2](#mypy-boto3-apigatewayv2)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `ApiGatewayV2` service.

```bash
python -m pip install boto3-stubs[apigatewayv2]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[apigatewayv2]` in your environment:
  `python -m pip install 'boto3-stubs[apigatewayv2]'`

Both type checking and auto-complete should work for `ApiGatewayV2` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[apigatewayv2]` in your environment:
  `python -m pip install 'boto3-stubs[apigatewayv2]'`

Both type checking and auto-complete should work for `ApiGatewayV2` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[apigatewayv2]` in your environment:
  `python -m pip install 'boto3-stubs[apigatewayv2]'`
- Run `mypy` as usual

Type checking should work for `ApiGatewayV2` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[apigatewayv2]` in your environment:
  `python -m pip install 'boto3-stubs[apigatewayv2]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ApiGatewayV2` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`ApiGatewayV2Client` provides annotations for `boto3.client("apigatewayv2")`.

```python
import boto3

from mypy_boto3_apigatewayv2 import ApiGatewayV2Client

client: ApiGatewayV2Client = boto3.client("apigatewayv2")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ApiGatewayV2Client = session.client("apigatewayv2")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_apigatewayv2.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_apigatewayv2 import ApiGatewayV2Client
from mypy_boto3_apigatewayv2.paginator import (
    GetApisPaginator,
    GetAuthorizersPaginator,
    GetDeploymentsPaginator,
    GetDomainNamesPaginator,
    GetIntegrationResponsesPaginator,
    GetIntegrationsPaginator,
    GetModelsPaginator,
    GetRouteResponsesPaginator,
    GetRoutesPaginator,
    GetStagesPaginator,
)

client: ApiGatewayV2Client = boto3.client("apigatewayv2")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_apis_paginator: GetApisPaginator = client.get_paginator("get_apis")
get_authorizers_paginator: GetAuthorizersPaginator = client.get_paginator("get_authorizers")
get_deployments_paginator: GetDeploymentsPaginator = client.get_paginator("get_deployments")
get_domain_names_paginator: GetDomainNamesPaginator = client.get_paginator("get_domain_names")
get_integration_responses_paginator: GetIntegrationResponsesPaginator = client.get_paginator("get_integration_responses")
get_integrations_paginator: GetIntegrationsPaginator = client.get_paginator("get_integrations")
get_models_paginator: GetModelsPaginator = client.get_paginator("get_models")
get_route_responses_paginator: GetRouteResponsesPaginator = client.get_paginator("get_route_responses")
get_routes_paginator: GetRoutesPaginator = client.get_paginator("get_routes")
get_stages_paginator: GetStagesPaginator = client.get_paginator("get_stages")
```

### Literals<a id="literals"></a>

`mypy_boto3_apigatewayv2.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_apigatewayv2.literals import (
    AuthorizationTypeType,
    AuthorizerTypeType,
    ConnectionTypeType,
    ContentHandlingStrategyType,
    DeploymentStatusType,
    DomainNameStatusType,
    EndpointTypeType,
    GetApisPaginatorName,
    GetAuthorizersPaginatorName,
    GetDeploymentsPaginatorName,
    GetDomainNamesPaginatorName,
    GetIntegrationResponsesPaginatorName,
    GetIntegrationsPaginatorName,
    GetModelsPaginatorName,
    GetRouteResponsesPaginatorName,
    GetRoutesPaginatorName,
    GetStagesPaginatorName,
    IntegrationTypeType,
    JSONYAMLType,
    LoggingLevelType,
    OAS30Type,
    PassthroughBehaviorType,
    ProtocolTypeType,
    SecurityPolicyType,
    VpcLinkStatusType,
    VpcLinkVersionType,
)

def check_value(value: AuthorizationTypeType) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_apigatewayv2.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_apigatewayv2.type_defs import (
    AccessLogSettingsTypeDef,
    ApiMappingTypeDef,
    ApiTypeDef,
    AuthorizerTypeDef,
    CorsTypeDef,
    CreateApiMappingResponseTypeDef,
    CreateApiResponseTypeDef,
    CreateAuthorizerResponseTypeDef,
    CreateDeploymentResponseTypeDef,
    CreateDomainNameResponseTypeDef,
    CreateIntegrationResponseResponseTypeDef,
    CreateIntegrationResultTypeDef,
    CreateModelResponseTypeDef,
    CreateRouteResponseResponseTypeDef,
    CreateRouteResultTypeDef,
    CreateStageResponseTypeDef,
    CreateVpcLinkResponseTypeDef,
    DeploymentTypeDef,
    DomainNameConfigurationTypeDef,
    DomainNameTypeDef,
    ExportApiResponseTypeDef,
    GetApiMappingResponseTypeDef,
    GetApiMappingsResponseTypeDef,
    GetApiResponseTypeDef,
    GetApisResponseTypeDef,
    GetAuthorizerResponseTypeDef,
    GetAuthorizersResponseTypeDef,
    GetDeploymentResponseTypeDef,
    GetDeploymentsResponseTypeDef,
    GetDomainNameResponseTypeDef,
    GetDomainNamesResponseTypeDef,
    GetIntegrationResponseResponseTypeDef,
    GetIntegrationResponsesResponseTypeDef,
    GetIntegrationResultTypeDef,
    GetIntegrationsResponseTypeDef,
    GetModelResponseTypeDef,
    GetModelTemplateResponseTypeDef,
    GetModelsResponseTypeDef,
    GetRouteResponseResponseTypeDef,
    GetRouteResponsesResponseTypeDef,
    GetRouteResultTypeDef,
    GetRoutesResponseTypeDef,
    GetStageResponseTypeDef,
    GetStagesResponseTypeDef,
    GetTagsResponseTypeDef,
    GetVpcLinkResponseTypeDef,
    GetVpcLinksResponseTypeDef,
    ImportApiResponseTypeDef,
    IntegrationResponseTypeDef,
    IntegrationTypeDef,
    JWTConfigurationTypeDef,
    ModelTypeDef,
    MutualTlsAuthenticationInputTypeDef,
    MutualTlsAuthenticationTypeDef,
    PaginatorConfigTypeDef,
    ParameterConstraintsTypeDef,
    ReimportApiResponseTypeDef,
    RouteResponseTypeDef,
    RouteSettingsTypeDef,
    RouteTypeDef,
    StageTypeDef,
    TlsConfigInputTypeDef,
    TlsConfigTypeDef,
    UpdateApiMappingResponseTypeDef,
    UpdateApiResponseTypeDef,
    UpdateAuthorizerResponseTypeDef,
    UpdateDeploymentResponseTypeDef,
    UpdateDomainNameResponseTypeDef,
    UpdateIntegrationResponseResponseTypeDef,
    UpdateIntegrationResultTypeDef,
    UpdateModelResponseTypeDef,
    UpdateRouteResponseResponseTypeDef,
    UpdateRouteResultTypeDef,
    UpdateStageResponseTypeDef,
    UpdateVpcLinkResponseTypeDef,
    VpcLinkTypeDef,
)

def get_structure() -> AccessLogSettingsTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-apigatewayv2` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-apigatewayv2 docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_apigatewayv2/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
